nbqol.env.pathutils
===================

.. automodule:: nbqol.env.pathutils

   
   .. rubric:: Functions

   .. autosummary::
   
      add_git_root_to_sys_path
      diffpath
      notebook_path
      path_to_git_root
   